# von-x

VON-X is a Python library enabling rapid deployment of Hyperledger Indy credential issuer services, specifically for integration with TheOrgBook

For deploying VON-X as an Issuer, it is likely best to start with an example project like [Permitify-X](https://github.com/cywolf/permitify-x),
which simulates a BC Registries credential issuer for TheOrgBook. This project includes the necessary Docker tooling and example configuration files.

API documentation is available at [ReadTheDocs](https://von-x.readthedocs.io/en/latest/).
